<?php
/**
 * @package   Barn2\woocommerce-multiple-email-recipients
 * @author    Barn2 Plugins <support@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */

namespace Barn2\Plugin\WC_Multiple_Email_Recipients\Admin\Wizard;

use Barn2\Plugin\WC_Multiple_Email_Recipients\Admin\Wizard\Steps\License_Verification;
use Barn2\Plugin\WC_Multiple_Email_Recipients\Admin\Wizard\Steps\Emails;
use Barn2\Plugin\WC_Multiple_Email_Recipients\Admin\Wizard\Steps\Upsell;
use Barn2\Plugin\WC_Multiple_Email_Recipients\Admin\Wizard\Steps\Completed;
use Barn2\Plugin\WC_Multiple_Email_Recipients\Util\Settings;
use Barn2\WMER_Lib\Plugin\License\EDD_Licensing;
use Barn2\WMER_Lib\Plugin\License\Plugin_License;
use Barn2\WMER_Lib\Plugin\Licensed_Plugin;
use Barn2\WMER_Lib\Registerable;
use Barn2\WMER_Lib\Util as Lib_Util;

class Setup_Wizard implements Registerable {

	private $plugin;

	private $wizard;

	public function __construct( Licensed_Plugin $plugin ) {

		$this->plugin = $plugin;

		$steps = [
			new License_Verification(),
			new Emails(),
			new Upsell(),
			new Completed(),
		];

		$wizard = new Wizard( $this->plugin, $steps );

		$wizard->configure(
			[
				'skip_url'        => admin_url( 'admin.php?page=wc-settings&tab=products&section=multiple-email-recipients' ),
				'license_tooltip' => esc_html__( 'The licence key is contained in your order confirmation email.', 'woocommerce-multiple-email-recipients' ),
				'wc_email_url'    => admin_url( 'admin.php?page=wc-settings&tab=email' ),
				'utm_id'          => 'wmer',
			]
		);

		$wizard->add_edd_api( EDD_Licensing::class );
		$wizard->add_license_class( Plugin_License::class );
		$wizard->add_restart_link( Settings::SECTION_SLUG, 'multiple_email_recipients_options' );

		$wizard->add_custom_asset(
			$plugin->get_dir_url() . 'assets/js/admin/wizard.min.js',
			Lib_Util::get_script_dependencies( $this->plugin, 'admin/wizard.min.js' )
		);

		$this->wizard = $wizard;

	}

	public function register() {
		$this->wizard->boot();

		add_action( 'admin_enqueue_scripts', [ $this, 'enqueue_additional_scripts' ], 21 );
	}

	public function enqueue_additional_scripts( $hook_suffix ) {
		if ( 'toplevel_page_' . $this->wizard->get_slug() !== $hook_suffix ) {
			return;
		}

		// $all_products_url = admin_url( 'edit.php?post_type=product' );
		// wp_add_inline_script( $this->wizard->get_slug(), 'const all_products_url = ' . wp_json_encode( $all_products_url ) . ';' );
		// wp_enqueue_style( 'wcbvp-setup-wizard-addons', $this->plugin->get_dir_url() . 'assets/css/admin/wizard.min.css', [ $this->wizard->get_slug() ], $this->plugin->get_version() );
	}

}
