<?php
/**
 * @package   Barn2\woocommerce-multiple-email-recipients
 * @author    Barn2 Plugins <support@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */

namespace Barn2\Plugin\WC_Multiple_Email_Recipients\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Multiple_Email_Recipients\Util\Settings,
	Barn2\Plugin\WC_Multiple_Email_Recipients\Dependencies\Barn2\Setup_Wizard\Step,
	Barn2\Plugin\WC_Multiple_Email_Recipients\Dependencies\Barn2\Setup_Wizard\Util as Wizard_Util;

class Emails extends Step {

	/**
	 * Configure the step.
	 */
	public function __construct() {
		$this->set_id( 'emails' );
		$this->set_name( __( 'Emails', 'woocommerce-multiple-email-recipients' ) );
		$this->set_title( __( 'Customer Emails', 'woocommerce-multiple-email-recipients' ) );
		$this->set_description( __( 'Add extra email addresses for your customers', 'woocommerce-multiple-email-recipients' ) );
	}

	/**
	 * {@inheritdoc}
	 */
	public function setup_fields() {
		$fields = [
			'customer_email_addresses' => [
				'type'  => 'number',
				'label' => __( 'Customer email addresses', 'woocommerce-multiple-email-recipients' ),
				'value' => get_option( 'multiple_email_recipients_customer_email_addresses' ),
			],
			'email_labels'             => [
				'type'       => 'text_array',
				'label'      => __( 'Additional email labels', 'woocommerce-multiple-email-recipients' ),
				'value'      => get_option( 'wmer_customer_email_labels' ),
				'conditions' => [
					'customer_email_addresses' => [
						'op'    => 'gt',
						'value' => 1,
					],
				],
			],
			'title'                    => [
				'type'       => 'heading',
				'title'      => __( 'Display additional email fields', 'woocommerce-multiple-email-recipients' ),
				'size'       => 'h3',
				'conditions' => [
					'customer_email_addresses' => [
						'op'    => 'gt',
						'value' => 1,
					],
				],
			],
			'account'                  => [
				'type'       => 'checkbox',
				'label'      => __( 'Account page', 'woocommerce-multiple-email-recipients' ),
				'value'      => get_option( 'multiple_email_recipients_display_account' ),
				'conditions' => [
					'customer_email_addresses' => [
						'op'    => 'gt',
						'value' => 1,
					],
				],
			],
			'checkout'                 => [
				'type'       => 'checkbox',
				'label'      => __( 'Checkout', 'woocommerce-multiple-email-recipients' ),
				'value'      => get_option( 'multiple_email_recipients_display_checkout' ),
				'conditions' => [
					'customer_email_addresses' => [
						'op'    => 'gt',
						'value' => 1,
					],
				],
			],
		];

		return $fields;
	}

	/**
	 * Update options in the database if needed.
	 *
	 * @return void
	 */
	public function submit() {
		check_ajax_referer( 'barn2_setup_wizard_nonce', 'nonce' );

		if ( ! current_user_can( 'manage_options' ) ) {
			$this->send_error( esc_html__( 'You are not authorized.', 'woocommerce-multiple-email-recipients' ) );
		}

		$values = $this->get_submitted_values();

		update_option( 'multiple_email_recipients_customer_email_addresses', $values['customer_email_addresses'] );
		update_option( 'wmer_customer_email_labels', $values['email_labels'] );

		if ( $values['account'] ) {
			update_option( 'multiple_email_recipients_display_account', 'yes' );
		} else {
			delete_option( 'multiple_email_recipients_display_account' );
		}

		if ( $values['account'] ) {
			update_option( 'multiple_email_recipients_display_checkout', 'yes' );
		} else {
			delete_option( 'multiple_email_recipients_display_checkout' );
		}

		wp_send_json_success();
	}

}
